@@ -7,22 +7,22 @@ our @EXPORT = qw/
     new
 /;
 our @EXPORT_OK = qw/
-    context session message text
-    is_text is_sticker is_link is_image is_location
+    context session event text
+    is_text is_image is_video is_audio is_location is_sticker
     context_is
 /;
 our %EXPORT_TAGS = (
     DSL => [ qw/
         new
-        context session message text
-        is_text is_sticker is_link is_image is_location
+        context session event text
+        is_text is_image is_video is_audio is_location is_sticker
         context_is
     / ],
 );
 
 our $CONTEXT;
 our $SESSION;
-our $MESSAGE;
+our $EVENT;
 our $TEXT;
 
 sub import {
@@ -46,15 +46,16 @@ sub new {
 
 sub context { $CONTEXT }
 sub session { $SESSION }
-sub message { $MESSAGE }
+sub event   { $EVENT }
 sub text    { $TEXT }
 
 # is
-sub is_text     { $MESSAGE->is_text; }
-sub is_sticker  { $MESSAGE->is_sticker; }
-sub is_link     { $MESSAGE->is_link; }
-sub is_image    { $MESSAGE->is_image; }
-sub is_location { $MESSAGE->is_location; }
+sub is_text     { $EVENT->is_text_message; }
+sub is_image    { $EVENT->is_image_message; }
+sub is_video    { $EVENT->is_video_message; }
+sub is_audio    { $EVENT->is_audio_message; }
+sub is_location { $EVENT->is_location_message; }
+sub is_sticker  { $EVENT->is_sticker_message; }
 
 # context
 sub context_is {
