@@ -5,6 +5,7 @@ use warnings;
 use Carp qw/ carp croak /;
 use File::Temp;
 use Furl::HTTP;
+use Furl::Headers;
 use JSON::XS;
 
 use LINE::Bot::API;
@@ -73,6 +74,7 @@ sub post {
 
     my $ret = $JSON->decode($res_content);
     $ret->{http_status} = $res_status;
+    $ret->{http_headers} = Furl::Headers->new($res_headers);
     $ret;
 }
 
